#!/bin/sh

#############################################
# que delete script
#############################################
LANG=C;export LANG
SCRIPT_DIR=`dirname $0`
LOG=${SCRIPT_DIR}/log/daedmon_check_`date +%Y%m%d`
UNAME=`uname -n`

## root dir load
. ${SCRIPT_DIR}/.root

ERROR_LOG=${ROOT}/que/error/DAEMON_ERROR_${UNAME}_`date +%Y%m%d`

DAEMON_CHECK=`ps -ef | grep ${ROOT}/sbin/ecron_clusterd | grep -v grep`

if [ "${DAEMON_CHECK}" = "" ];then
 echo "`date` daemon don't running !! ${UNAME}" >> ${LOG}
 echo "`date` daemon don't running !!" ${UNAME} >> ${ERROR_LOG}
 ${ROOT}/sbin/ecron_clusterd &
fi

sleep 2

DAEMON_CHECK=`ps -ef | grep ${ROOT}/sbin/ecron_clusterd | grep -v grep` 
if [ "${DAEMON_CHECK}" = "" ];then
 echo "`date` daemon can't start !!" >> ${LOG}
 echo "`date` daemon can't start !! ${UAME}" >> ${ERROR_LOG}
fi

exit 0
